@@ -4,6 +4,7 @@ import argparse
 import json
 import os
 import pathlib
+import typing
 
 
 def JsonFileOrStrType(arg):
@@ -25,7 +26,7 @@ def JsonFileOrStrType(arg):
 
 
 class KeyValuePairsAction(argparse.Action):
-    value_dict: dict[str, str] = {}
+    value_dict: dict[str, typing.Any] = {}
 
     def __call__(self, parser, namespace, values, option_string):
         for pair in values:
@@ -34,7 +35,13 @@ class KeyValuePairsAction(argparse.Action):
                 raise parser.error(
                     f"Key '{key}' was defined multiple times for '{self.dest}'"
                 )
-            self.value_dict[key] = value
+            # Attempt to parse the value to better handle numbers, booleans, etc
+            parsed_value = value
+            try:
+                parsed_value = json.loads(value)
+            except json.decoder.JSONDecodeError:
+                pass  # swallow
+            self.value_dict[key] = parsed_value
 
         setattr(namespace, self.dest, self.value_dict)
 
