@@ -2,21 +2,27 @@
 
 from typing import Optional
 
-from ..domain.actions import ActionDelegate
+from ..domain.actions import (
+    ActionDelegate,
+    InvocationDelegate,
+)
 from ..domain.datasets import DatasetDelegate
 from ..domain.orgs import OrgDelegate
 from ..domain.tokens import TokenDelegate
 from ..domain.triggers import TriggerDelegate
+from ..domain.users import UserDelegate
 from ..http import HttpClient
 
 
 class CLIContext:
     _http: Optional[HttpClient]
+    actions: ActionDelegate
     datasets: DatasetDelegate
+    invocations: InvocationDelegate
     orgs: OrgDelegate
     tokens: TokenDelegate
     triggers: TriggerDelegate
-    actions: ActionDelegate
+    users: UserDelegate
 
     @property
     def http(self) -> HttpClient:
