@@ -2,6 +2,10 @@ from typing import Any, Optional
 
 import pydantic
 
+from .action_container_resources import (
+    ComputeRequirements,
+    ContainerParameters,
+)
 from .action_delegate import UpdateCondition
 
 
@@ -13,6 +17,8 @@ class CreateActionRequest(pydantic.BaseModel):
     description: Optional[str] = None
     metadata: Optional[dict[str, Any]] = pydantic.Field(default_factory=dict)
     tags: Optional[list[str]] = pydantic.Field(default_factory=list)
+    compute_requirements: Optional[ComputeRequirements] = None
+    container_parameters: Optional[ContainerParameters] = None
 
 
 class ContainerUploadCredentials(pydantic.BaseModel):
