@@ -3,6 +3,11 @@ from typing import Any, Optional
 
 import pydantic
 
+from .action_container_resources import (
+    ComputeRequirements,
+    ContainerParameters,
+)
+
 
 class ActionRecord(pydantic.BaseModel):
     """
@@ -18,9 +23,13 @@ class ActionRecord(pydantic.BaseModel):
     name: str  # Sort key
     org_id: str  # Partition key
 
+    compute_requirements: ComputeRequirements = pydantic.Field(
+        default_factory=ComputeRequirements
+    )
+    container_parameters: ContainerParameters = pydantic.Field(
+        default_factory=ContainerParameters
+    )
     description: Optional[str] = None
-    # Linked to `uri`; an Action may have a URI set but the container expected at that URI may not be available
-    is_available: bool = False
     metadata: Optional[dict[str, Any]] = None
     tags: Optional[list[str]] = None
     uri: Optional[str] = None
