@@ -2,6 +2,10 @@ from typing import Optional
 
 import pydantic
 
+from .action_container_resources import (
+    ComputeRequirements,
+    ContainerParameters,
+)
 from .invocation_record import (
     InvocationDataSourceType,
     InvocationSource,
@@ -11,6 +15,8 @@ from .invocation_record import (
 
 class CreateInvocationRequest(pydantic.BaseModel):
     input_data: list[str]
+    compute_requirements: ComputeRequirements
+    container_parameters: ContainerParameters
     data_source_id: str
     data_source_type: InvocationDataSourceType
     invocation_source: InvocationSource
