@@ -7,6 +7,9 @@ from .http_resources import (
     BindEmailDomainRequest,
     CreateOrgRequest,
     InviteUserRequest,
+    ModifyRoleForUserRequest,
+    RemoveUserFromOrgRequest,
+    UpdateOrgRequest,
 )
 from .org import Org
 from .org_invite import OrgInvite
@@ -24,6 +27,9 @@ __all__ = [
     "BindEmailDomainRequest",
     "CreateOrgRequest",
     "InviteUserRequest",
+    "RemoveUserFromOrgRequest",
+    "ModifyRoleForUserRequest",
+    "UpdateOrgRequest",
     "Org",
     "OrgDelegate",
     "OrgHttpDelegate",
