@@ -14,19 +14,29 @@ class OrgRole:
     __org: Org
 
     @classmethod
-    def by_user_id(
+    def for_user(
         cls, user_id: Optional[str], org_delegate: OrgDelegate
     ) -> list["OrgRole"]:
         records = org_delegate.org_roles_for_user(user_id=user_id)
         return [cls(record=record, org_delegate=org_delegate) for record in records]
 
     @classmethod
-    def by_org_id(
+    def for_org(
         cls, org_id: Optional[str], org_delegate: OrgDelegate
     ) -> list["OrgRole"]:
         records = org_delegate.org_roles_for_org(org_id=org_id)
         return [cls(record=record, org_delegate=org_delegate) for record in records]
 
+    @classmethod
+    def for_user_in_org(
+        cls,
+        org_delegate: OrgDelegate,
+        user_id: Optional[str] = None,
+        org_id: Optional[str] = None,
+    ):
+        record = org_delegate.org_role_for_user_in_org(user_id=user_id, org_id=org_id)
+        return cls(record=record, org_delegate=org_delegate)
+
     def __init__(self, record: OrgRoleRecord, org_delegate: OrgDelegate):
         self.__record = record
         self.__org_delegate = org_delegate
