@@ -10,16 +10,16 @@ class TokenDelegate(abc.ABC):
         super().__init__()
 
     @abc.abstractmethod
-    def get_tokens_for_user(self, user_id: Optional[str]) -> list[TokenRecord]:
+    def get_tokens_for_user(self, user_id: Optional[str] = None) -> list[TokenRecord]:
         raise NotImplementedError("get_tokens_for_user")
 
     @abc.abstractmethod
     def create_token(
         self,
-        user_id: Optional[str],
         expiry_days: int,
         name: str,
-        description: Optional[str],
+        user_id: Optional[str] = None,
+        description: Optional[str] = None,
     ) -> TokenRecord:
         raise NotImplementedError("create_token")
 
