@@ -2,9 +2,10 @@
 
 from typing import Optional
 
+from ...exceptions import RobotoHttpExceptionParse
 from ...http import (
-    USER_OVERRIDE_HEADER,
     HttpClient,
+    headers_for_org_and_user,
 )
 from .user_delegate import UserDelegate
 from .user_record import UserRecord
@@ -17,19 +18,18 @@ class UserHttpDelegate(UserDelegate):
         super().__init__()
         self.__http_client = http_client
 
-    def get_user_by_id(self, user_id: Optional[str]) -> UserRecord:
+    def get_user_by_id(self, user_id: Optional[str] = None) -> UserRecord:
         url = self.__http_client.url("v1/users")
-        headers = {}
-        if user_id is not None:
-            headers[USER_OVERRIDE_HEADER] = user_id
+        headers = headers_for_org_and_user(user_id=user_id)
+
+        with RobotoHttpExceptionParse():
+            response = self.__http_client.get(url=url, headers=headers)
 
-        response = self.__http_client.get(url=url, headers=headers)
         return UserRecord.parse_obj(response.from_json(json_path=["data"]))
 
-    def delete_user(self, user_id: Optional[str]) -> None:
+    def delete_user(self, user_id: Optional[str] = None) -> None:
         url = self.__http_client.url("v1/users")
-        headers = {}
-        if user_id is not None:
-            headers[USER_OVERRIDE_HEADER] = user_id
+        headers = headers_for_org_and_user(user_id=user_id)
 
-        self.__http_client.delete(url=url, headers=headers)
+        with RobotoHttpExceptionParse():
+            self.__http_client.delete(url=url, headers=headers)
