@@ -12,7 +12,7 @@ class User:
     __user_delegate: UserDelegate
 
     @classmethod
-    def by_id(cls, user_id: Optional[str], user_delegate: UserDelegate):
+    def from_id(cls, user_delegate: UserDelegate, user_id: Optional[str] = None):
         record = user_delegate.get_user_by_id(user_id=user_id)
         return cls(record=record, user_delegate=user_delegate)
 
@@ -20,8 +20,8 @@ class User:
         self.__record = record
         self.__user_delegate = user_delegate
 
-    def to_dict(self) -> dict[str, Any]:
-        return pydantic_jsonable_dict(self.__record)
+    def to_dict(self, exclude_none: bool = False) -> dict[str, Any]:
+        return pydantic_jsonable_dict(self.__record, exclude_none=exclude_none)
 
     def delete(self) -> None:
         return self.__user_delegate.delete_user(user_id=self.__record.user_id)
@@ -41,3 +41,11 @@ class User:
             if self.__record.is_system_user is not None
             else False
         )
+
+    @property
+    def name(self) -> Optional[str]:
+        return self.__record.name
+
+    @property
+    def picture_url(self) -> Optional[str]:
+        return self.__record.picture_url
