@@ -11,9 +11,9 @@ class UserDelegate(abc.ABC):
         super().__init__()
 
     @abc.abstractmethod
-    def get_user_by_id(self, user_id: Optional[str]) -> UserRecord:
+    def get_user_by_id(self, user_id: Optional[str] = None) -> UserRecord:
         raise NotImplementedError("get_user_by_id")
 
     @abc.abstractmethod
-    def delete_user(self, user_id: Optional[str]) -> None:
+    def delete_user(self, user_id: Optional[str] = None) -> None:
         raise NotImplementedError("delete_user")
