@@ -8,3 +8,5 @@ import pydantic
 class UserRecord(pydantic.BaseModel):
     user_id: str
     is_system_user: Optional[bool] = False
+    name: Optional[str] = None
+    picture_url: Optional[str] = None
