@@ -4,6 +4,7 @@ from .constants import (
     USER_OVERRIDE_HEADER,
     USER_OVERRIDE_QUERY_PARAM,
 )
+from .headers import headers_for_org_and_user
 from .http_client import (
     ClientError,
     HttpClient,
@@ -18,6 +19,7 @@ from .request_decorators import (
 from .testing_util import FakeHttpResponseFactory
 
 __all__ = (
+    "headers_for_org_and_user",
     "ClientError",
     "FakeHttpResponseFactory",
     "HttpClient",
